Accepting request 561753 from home:dimstar:Factory

Fix build with poppler 0.62 - will take a while to build, but the build fail usually happened in the first 5 minutes, which is well passed already

OBS-URL: https://build.opensuse.org/request/show/561753
OBS-URL: https://build.opensuse.org/package/show/LibreOffice:Factory/libreoffice?expand=0&rev=575
This commit is contained in:
Tomáš Chvátal 2018-01-05 10:23:29 +00:00 committed by Git OBS Bridge
parent 394fb3ece2
commit 9437783396
3 changed files with 40 additions and 0 deletions

View File

@ -0,0 +1,31 @@
Index: libreoffice-6.0.0.1/sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx
===================================================================
--- libreoffice-6.0.0.1.orig/sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx
+++ libreoffice-6.0.0.1/sdext/source/pdfimport/xpdfwrapper/pdfioutdev_gpl.cxx
@@ -32,10 +32,12 @@
#pragma warning(push, 1)
#endif
// sigh, UTF8.h was removed in poppler-0.21.0 and put back in 0.21.1
// FIXME: we can't use #if POPPLER_CHECK_VERSION(0, 21, 0) && !POPPLER_CHECK_VERSION(0, 21, 1)
// because the internal poppler does not provide poppler-version.h and the macro always returns 0
-#if POPPLER_CHECK_VERSION(0, 21, 1)
+#if POPPLER_CHECK_VERSION(0, 62, 0)
+#include <UnicodeMapFuncs.h>
+#elif POPPLER_CHECK_VERSION(0, 21, 1)
#include <UTF8.h>
#elif POPPLER_CHECK_VERSION(0, 21, 0)
#include "UTF.h"
@@ -913,7 +915,11 @@ void PDFOutDev::drawChar(GfxState *state
);
// silence spurious warning
+#if POPPLER_CHECK_VERSION(0, 62, 0)
+ (void)&mapUTF16;
+#else
(void)&mapUCS2;
+#endif
char buf[9];
for( int i=0; i<uLen; ++i )

View File

@ -1,3 +1,10 @@
-------------------------------------------------------------------
Thu Jan 4 21:30:45 UTC 2018 - dimstar@opensuse.org
- Add libreoffice-poppler-0.62.patch: Fix build with poppler 0.62,
where UTF8.h (explcitly marked as an experimental header) was
renamed to UnicodeMapFuncs.h.
-------------------------------------------------------------------
Tue Jan 2 12:51:58 UTC 2018 - tchvatal@suse.com

View File

@ -92,6 +92,7 @@ Patch1: scp2-user-config-suse.diff
Patch4: nlpsolver-no-broken-help.diff
Patch5: mediawiki-no-broken-help.diff
Patch6: kde5-configure-checks.patch
Patch7: libreoffice-poppler-0.62.patch
# try to save space by using hardlinks
Patch990: install-with-hardlinks.diff
BuildRequires: %{name}-share-linker
@ -885,6 +886,7 @@ Provides additional %{langname} translations and resources for %{project}. \
%patch4
%patch5
%patch6 -p1
@@ -32,10 +32,12 @@
#pragma warning(push, 1)
#endif
-// sigh, UTF8.h was removed in poppler-0.21.0 and put back in 0.21.1
+// sigh, UTF8.h was removed in poppler-0.21.0 and put back in 0.21.1, then renamed to UnicodeMapFuncs.h in 0.62.0
// FIXME: we can't use #if POPPLER_CHECK_VERSION(0, 21, 0) && !POPPLER_CHECK_VERSION(0, 21, 1)
// because the internal poppler does not provide poppler-version.h and the macro always returns 0
%patch7 -p1
%patch990 -p1
# Disable some of the failing tests (some are random)